@@ -33,6 +33,7 @@
 #include <dbus/dbus-shell.h>
 #include <dbus/dbus-spawn.h>
 #include <dbus/dbus-timeout.h>
+#include <dbus/dbus-sysdeps.h>
 #include <dirent.h>
 #include <errno.h>
 
@@ -284,22 +285,16 @@ update_desktop_file_entry (BusActivation       *activation,
   if (!bus_desktop_file_get_string (desktop_file,
                                     DBUS_SERVICE_SECTION,
                                     DBUS_SERVICE_NAME,
-                                    &name))
-    {
-      dbus_set_error (error, DBUS_ERROR_FAILED,
-                      "No \""DBUS_SERVICE_NAME"\" key in .service file\n");
-      goto failed;
-    }
+                                    &name,
+                                    error))
+    goto failed;
 
   if (!bus_desktop_file_get_string (desktop_file,
                                     DBUS_SERVICE_SECTION,
                                     DBUS_SERVICE_EXEC,
-                                    &exec))
-    {
-      dbus_set_error (error, DBUS_ERROR_FAILED,
-                      "No \""DBUS_SERVICE_EXEC"\" key in .service file\n");
-      goto failed;
-    }
+                                    &exec,
+                                    error))
+    goto failed;
 
   entry = _dbus_hash_table_lookup_string (s_dir->entries, 
                                           _dbus_string_get_const_data (filename));
@@ -465,7 +460,10 @@ check_service_file (BusActivation       *activation,
               retval = TRUE;
               goto out;
             }
-          
+         
+          /* @todo We can return OOM or a DBUS_ERROR_FAILED error 
+           *       Handle these both better
+           */ 
           if (!update_desktop_file_entry (activation, entry->s_dir, &filename, desktop_file, &tmp_error))
             {
               bus_desktop_file_free (desktop_file);
@@ -592,6 +590,9 @@ update_directory (BusActivation       *activation,
           continue;
         }
 
+      /* @todo We can return OOM or a DBUS_ERROR_FAILED error 
+       *       Handle these both better
+       */ 
       if (!update_desktop_file_entry (activation, s_dir, &filename, desktop_file, &tmp_error))
         {
           bus_desktop_file_free (desktop_file);
@@ -633,8 +634,6 @@ update_directory (BusActivation       *activation,
   
   if (iter != NULL)
     _dbus_directory_close (iter);
-  if (desktop_file)
-    bus_desktop_file_free (desktop_file);
   _dbus_string_free (&filename);
   _dbus_string_free (&full_path);
   
@@ -1920,8 +1919,11 @@ bus_activation_service_reload_test (const DBusString *test_data_dir)
 
   if (!_dbus_string_init (&directory))
     return FALSE;
-
-  if (!_dbus_string_append (&directory, "/tmp/dbus-reload-test-") ||
+  
+  if (!_dbus_string_append (&directory, _dbus_get_tmpdir()))
+    return FALSE;
+  
+  if (!_dbus_string_append (&directory, "/dbus-reload-test-") ||
       !_dbus_generate_random_ascii (&directory, 6))
      {
        return FALSE;
