@@ -28,6 +28,7 @@
 #include "dbus-message.h"
 #include "dbus-marshal-validate.h"
 #include "dbus-threads-internal.h"
+#include "dbus-connection-internal.h"
 #include <string.h>
 
 /**
@@ -303,20 +304,29 @@ ensure_bus_data (DBusConnection *connection)
 }
 
 /* internal function that checks to see if this
-   is a shared bus connection and if it is unref it */
+   is a shared connection owned by the bus and if it is unref it */
 void
-_dbus_bus_check_connection_and_unref (DBusConnection *connection)
+_dbus_bus_check_connection_and_unref_unlocked (DBusConnection *connection)
 {
+  _DBUS_LOCK (bus);
+
   if (bus_connections[DBUS_BUS_SYSTEM] == connection)
     {
       bus_connections[DBUS_BUS_SYSTEM] = NULL;
-      dbus_connection_unref (connection);
+      _dbus_connection_unref_unlocked (connection);
     }
   else if (bus_connections[DBUS_BUS_SESSION] == connection)
     {
       bus_connections[DBUS_BUS_SESSION] = NULL;
-      dbus_connection_unref (connection);
+      _dbus_connection_unref_unlocked (connection);
     }
+  else if (bus_connections[DBUS_BUS_STARTER] == connection)
+    {
+      bus_connections[DBUS_BUS_STARTER] = NULL;
+      _dbus_connection_unref_unlocked (connection);
+    }
+
+  _DBUS_UNLOCK (bus);
 }
 
 static DBusConnection *
@@ -394,7 +404,7 @@ internal_bus_get (DBusBusType  type,
   if (!dbus_bus_register (connection, error))
     {
       _DBUS_ASSERT_ERROR_IS_SET (error);
-      dbus_connection_close (connection);
+      _dbus_connection_close_internal (connection);
       dbus_connection_unref (connection);
 
       _DBUS_UNLOCK (bus);
@@ -670,7 +680,7 @@ dbus_bus_get_unix_user (DBusConnection *connection,
 /**
  * Asks the bus to assign the given name to this connection by invoking
  * the RequestName method on the bus. This method is fully documented
- * in the D-BUS specification. For quick reference, the flags and
+ * in the D-Bus specification. For quick reference, the flags and
  * result codes are discussed here, but the specification is the
  * canonical version of this information.
  *
@@ -797,7 +807,7 @@ dbus_bus_request_name (DBusConnection *connection,
 /**
  * Asks the bus to unassign the given name to this connection by invoking
  * the ReleaseName method on the bus. This method is fully documented
- * in the D-BUS specification.
+ * in the D-Bus specification.
  *
  * @param connection the connection
  * @param name the name to remove 
@@ -1047,7 +1057,7 @@ send_no_return_values (DBusConnection *connection,
  * but that would require blocking always to determine
  * the return value.
  *
- * The AddMatch method is fully documented in the D-BUS 
+ * The AddMatch method is fully documented in the D-Bus 
  * specification. For quick reference, the format of the 
  * match rules is discussed here, but the specification 
  * is the canonical version of this information.
@@ -1156,16 +1166,4 @@ dbus_bus_remove_match (DBusConnection *connection,
   dbus_message_unref (msg);
 }
 
-#ifdef DBUS_BUILD_TESTS
-const char *
-dbus_bus_connection_get_unique_name (DBusConnection *connection)
-{
-  BusData *bd;
-  bd = dbus_connection_get_data (connection, bus_data_slot);
-  
-  return bd->unique_name;
-}
-#endif /* DBUS_BUILD_TESTS */
-
-
 /** @} */
