@@ -1,5 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
-/* dbus-internals.c  random utility stuff (internal to D-BUS implementation)
+/* dbus-internals.c  random utility stuff (internal to D-Bus implementation)
  *
  * Copyright (C) 2002, 2003  Red Hat, Inc.
  *
@@ -28,13 +28,12 @@
 #include <string.h>
 #include <sys/types.h>
 #include <errno.h>
-#include <unistd.h>
 #include <fcntl.h>
 #include <stdlib.h>
 
 /**
- * @defgroup DBusInternals D-BUS internal implementation details
- * @brief Documentation useful when developing or debugging D-BUS itself.
+ * @defgroup DBusInternals D-Bus internal implementation details
+ * @brief Documentation useful when developing or debugging D-Bus itself.
  * 
  */
 
@@ -97,6 +96,38 @@
  *
  * @param object the object to be zeroed.
  */
+/**
+ * @def _DBUS_INT16_MIN
+ *
+ * Minimum value of type "int16"
+ */
+/**
+ * @def _DBUS_INT16_MAX
+ *
+ * Maximum value of type "int16"
+ */
+/**
+ * @def _DBUS_UINT16_MAX
+ *
+ * Maximum value of type "uint16"
+ */
+
+/**
+ * @def _DBUS_INT32_MIN
+ *
+ * Minimum value of type "int32"
+ */
+/**
+ * @def _DBUS_INT32_MAX
+ *
+ * Maximum value of type "int32"
+ */
+/**
+ * @def _DBUS_UINT32_MAX
+ *
+ * Maximum value of type "uint32"
+ */
+
 /**
  * @def _DBUS_INT_MIN
  *
@@ -107,6 +138,11 @@
  *
  * Maximum value of type "int"
  */
+/**
+ * @def _DBUS_UINT_MAX
+ *
+ * Maximum value of type "uint"
+ */
 
 /**
  * @typedef DBusForeachFunction
@@ -174,7 +210,33 @@ _dbus_warn (const char *format,
   va_end (args);
 }
 
+#ifdef DBUS_ENABLE_VERBOSE_MODE
+
 static dbus_bool_t verbose_initted = FALSE;
+static dbus_bool_t verbose = TRUE;
+
+#define PTHREAD_IN_VERBOSE 0
+#if PTHREAD_IN_VERBOSE
+#include <pthread.h>
+#endif
+
+static inline void
+_dbus_verbose_init (void)
+{
+  if (!verbose_initted)
+    {
+      const char *p = _dbus_getenv ("DBUS_VERBOSE"); 
+      verbose = p != NULL && *p == '1';
+      verbose_initted = TRUE;
+    }
+}
+
+dbus_bool_t
+_dbus_is_verbose_real (void)
+{
+  _dbus_verbose_init ();
+  return verbose;
+}
 
 /**
  * Prints a warning message to stderr
@@ -189,7 +251,6 @@ _dbus_verbose_real (const char *format,
                     ...)
 {
   va_list args;
-  static dbus_bool_t verbose = TRUE;
   static dbus_bool_t need_pid = TRUE;
   int len;
   
@@ -197,20 +258,19 @@ _dbus_verbose_real (const char *format,
    * in the non-verbose case we just have the one
    * conditional and return immediately.
    */
-  if (!verbose)
+  if (!_dbus_is_verbose_real())
     return;
-  
-  if (!verbose_initted)
-    {
-      verbose = _dbus_getenv ("DBUS_VERBOSE") != NULL;
-      verbose_initted = TRUE;
-      if (!verbose)
-        return;
-    }
 
   /* Print out pid before the line */
   if (need_pid)
-    fprintf (stderr, "%lu: ", _dbus_getpid ());
+    {
+#if PTHREAD_IN_VERBOSE
+      fprintf (stderr, "%lu: 0x%lx: ", _dbus_getpid (), pthread_self ());
+#else
+      fprintf (stderr, "%lu: ", _dbus_getpid ());
+#endif
+    }
+      
 
   /* Only print pid again if the next line is a new line */
   len = strlen (format);
@@ -238,6 +298,8 @@ _dbus_verbose_reset_real (void)
   verbose_initted = FALSE;
 }
 
+#endif /* DBUS_ENABLE_VERBOSE_MODE */
+
 /**
  * Duplicates a string. Result must be freed with
  * dbus_free(). Returns #NULL if memory allocation fails.
@@ -354,42 +416,7 @@ _dbus_string_array_contains (const char **array,
   return FALSE;
 }
 
-/**
- * Returns a string describing the given type.
- *
- * @param type the type to describe
- * @returns a constant string describing the type
- */
-const char *
-_dbus_type_to_string (int type)
-{
-  switch (type)
-    {
-    case DBUS_TYPE_INVALID:
-      return "invalid";
-    case DBUS_TYPE_NIL:
-      return "nil";
-    case DBUS_TYPE_BOOLEAN:
-      return "boolean";
-    case DBUS_TYPE_INT32:
-      return "int32";
-    case DBUS_TYPE_UINT32:
-      return "uint32";
-    case DBUS_TYPE_DOUBLE:
-      return "double";
-    case DBUS_TYPE_STRING:
-      return "string";
-    case DBUS_TYPE_CUSTOM:
-      return "custom";
-    case DBUS_TYPE_ARRAY:
-      return "array";
-    case DBUS_TYPE_DICT:
-      return "dict";
-    default:
-      return "unknown";
-    }
-}
-
+#ifdef DBUS_BUILD_TESTS
 /**
  * Returns a string describing the given name.
  *
@@ -423,12 +450,13 @@ _dbus_header_field_to_string (int header_field)
       return "unknown";
     }
 }
+#endif /* DBUS_BUILD_TESTS */
 
 #ifndef DBUS_DISABLE_CHECKS
 /** String used in _dbus_return_if_fail macro */
 const char _dbus_return_if_fail_warning_format[] =
 "%lu: arguments to %s() were incorrect, assertion \"%s\" failed in file %s line %d.\n"
-"This is normally a bug in some application using the D-BUS library.\n";
+"This is normally a bug in some application using the D-Bus library.\n";
 #endif
 
 #ifndef DBUS_DISABLE_ASSERT
@@ -442,17 +470,19 @@ const char _dbus_return_if_fail_warning_format[] =
  * @param condition_text condition as a string
  * @param file file the assertion is in
  * @param line line the assertion is in
+ * @param func function the assertion is in
  */
 void
 _dbus_real_assert (dbus_bool_t  condition,
                    const char  *condition_text,
                    const char  *file,
-                   int          line)
+                   int          line,
+                   const char  *func)
 {
   if (_DBUS_UNLIKELY (!condition))
     {
-      _dbus_warn ("%lu: assertion failed \"%s\" file \"%s\" line %d\n",
-                  _dbus_getpid (), condition_text, file, line);
+      _dbus_warn ("%lu: assertion failed \"%s\" file \"%s\" line %d function %s\n",
+                  _dbus_getpid (), condition_text, file, line, func);
       _dbus_abort ();
     }
 }
@@ -525,6 +555,9 @@ _dbus_test_oom_handling (const char             *description,
                          void                   *data)
 {
   int approx_mallocs;
+  const char *setting;
+  int max_failures_to_try;
+  int i;
 
   /* Run once to see about how many mallocs are involved */
   
@@ -540,21 +573,30 @@ _dbus_test_oom_handling (const char             *description,
   _dbus_verbose ("\n=================\n%s: about %d mallocs total\n=================\n",
                  description, approx_mallocs);
 
-  _dbus_set_fail_alloc_failures (1);
-  if (!run_failing_each_malloc (approx_mallocs, description, func, data))
-    return FALSE;
+  setting = _dbus_getenv ("DBUS_TEST_MALLOC_FAILURES");
+  if (setting != NULL)
+    {
+      DBusString str;
+      long v;
+      _dbus_string_init_const (&str, setting);
+      v = 4;
+      if (!_dbus_string_parse_int (&str, 0, &v, NULL))
+        _dbus_warn ("couldn't parse '%s' as integer\n", setting);
+      max_failures_to_try = v;
+    }
+  else
+    {
+      max_failures_to_try = 4;
+    }
 
-  _dbus_set_fail_alloc_failures (2);
-  if (!run_failing_each_malloc (approx_mallocs, description, func, data))
-    return FALSE;
-  
-  _dbus_set_fail_alloc_failures (3);
-  if (!run_failing_each_malloc (approx_mallocs, description, func, data))
-    return FALSE;
-
-  _dbus_set_fail_alloc_failures (4);
-  if (!run_failing_each_malloc (approx_mallocs, description, func, data))
-    return FALSE;
+  i = setting ? max_failures_to_try - 1 : 1;
+  while (i < max_failures_to_try)
+    {
+      _dbus_set_fail_alloc_failures (i);
+      if (!run_failing_each_malloc (approx_mallocs, description, func, data))
+        return FALSE;
+      ++i;
+    }
   
   _dbus_verbose ("\n=================\n%s: all iterations passed\n=================\n",
                  description);
