@@ -1,7 +1,7 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
 /* dbus-message.h DBusMessage object
  *
- * Copyright (C) 2002, 2003 Red Hat Inc.
+ * Copyright (C) 2002, 2003, 2005 Red Hat Inc.
  *
  * Licensed under the Academic Free License version 2.1
  * 
@@ -61,7 +61,7 @@ struct DBusMessageIter
 };
 
 DBusMessage* dbus_message_new               (int          message_type);
-DBusMessage* dbus_message_new_method_call   (const char  *service,
+DBusMessage* dbus_message_new_method_call   (const char  *bus_name,
                                              const char  *path,
                                              const char  *interface,
                                              const char  *method);
@@ -85,12 +85,18 @@ int           dbus_message_get_type         (DBusMessage   *message);
 dbus_bool_t   dbus_message_set_path         (DBusMessage   *message,
                                              const char    *object_path);
 const char*   dbus_message_get_path         (DBusMessage   *message);
+dbus_bool_t   dbus_message_has_path         (DBusMessage   *message, 
+                                             const char    *object_path);  
 dbus_bool_t   dbus_message_set_interface    (DBusMessage   *message,
-                                             const char    *interface);
+                                             const char    *interface);       
 const char*   dbus_message_get_interface    (DBusMessage   *message);
+dbus_bool_t   dbus_message_has_interface    (DBusMessage   *message, 
+                                             const char    *interface);
 dbus_bool_t   dbus_message_set_member       (DBusMessage   *message,
                                              const char    *member);
 const char*   dbus_message_get_member       (DBusMessage   *message);
+dbus_bool_t   dbus_message_has_member       (DBusMessage   *message, 
+                                             const char    *member);
 dbus_bool_t   dbus_message_set_error_name   (DBusMessage   *message,
                                              const char    *name);
 const char*   dbus_message_get_error_name   (DBusMessage   *message);
@@ -113,9 +119,9 @@ dbus_bool_t   dbus_message_is_signal        (DBusMessage   *message,
 dbus_bool_t   dbus_message_is_error         (DBusMessage   *message,
                                              const char    *error_name);
 dbus_bool_t   dbus_message_has_destination  (DBusMessage   *message,
-                                             const char    *service);
+                                             const char    *bus_name);
 dbus_bool_t   dbus_message_has_sender       (DBusMessage   *message,
-                                             const char    *service);
+                                             const char    *unique_bus_name);
 dbus_bool_t   dbus_message_has_signature    (DBusMessage   *message,
                                              const char    *signature);
 dbus_uint32_t dbus_message_get_serial       (DBusMessage   *message);
@@ -123,9 +129,9 @@ dbus_bool_t   dbus_message_set_reply_serial (DBusMessage   *message,
                                              dbus_uint32_t  reply_serial);
 dbus_uint32_t dbus_message_get_reply_serial (DBusMessage   *message);
 
-void          dbus_message_set_auto_activation (DBusMessage   *message,
-						dbus_bool_t    auto_activation);
-dbus_bool_t   dbus_message_get_auto_activation (DBusMessage   *message);
+void          dbus_message_set_auto_start   (DBusMessage   *message,
+                                             dbus_bool_t    auto_start);
+dbus_bool_t   dbus_message_get_auto_start   (DBusMessage   *message);
 
 dbus_bool_t   dbus_message_get_path_decomposed (DBusMessage   *message,
                                                 char        ***path);
@@ -144,141 +150,40 @@ dbus_bool_t dbus_message_get_args_valist      (DBusMessage     *message,
 					       DBusError       *error,
 					       int              first_arg_type,
 					       va_list          var_args);
-dbus_bool_t dbus_message_iter_get_args        (DBusMessageIter *iter,
-					       DBusError       *error,
-					       int              first_arg_type,
-					       ...);
-dbus_bool_t dbus_message_iter_get_args_valist (DBusMessageIter *iter,
-					       DBusError       *error,
-					       int              first_arg_type,
-					       va_list          var_args);
 
 
-dbus_bool_t            dbus_message_iter_init            (DBusMessage      *message,
-                                                          DBusMessageIter  *iter);
-dbus_bool_t            dbus_message_iter_has_next        (DBusMessageIter  *iter);
-dbus_bool_t            dbus_message_iter_next            (DBusMessageIter  *iter);
-int                    dbus_message_iter_get_arg_type    (DBusMessageIter  *iter);
-int                    dbus_message_iter_get_array_type  (DBusMessageIter  *iter);
-unsigned char          dbus_message_iter_get_byte        (DBusMessageIter  *iter);
-dbus_bool_t            dbus_message_iter_get_boolean     (DBusMessageIter  *iter);
-dbus_int32_t           dbus_message_iter_get_int32       (DBusMessageIter  *iter);
-dbus_uint32_t          dbus_message_iter_get_uint32      (DBusMessageIter  *iter);
-#ifdef DBUS_HAVE_INT64
-dbus_int64_t           dbus_message_iter_get_int64       (DBusMessageIter  *iter);
-dbus_uint64_t          dbus_message_iter_get_uint64      (DBusMessageIter  *iter);
-#endif /* DBUS_HAVE_INT64 */
-double                 dbus_message_iter_get_double      (DBusMessageIter  *iter);
-char *                 dbus_message_iter_get_string      (DBusMessageIter  *iter);
-char *                 dbus_message_iter_get_object_path (DBusMessageIter  *iter);
-char *                 dbus_message_iter_get_dict_key    (DBusMessageIter  *iter);
-dbus_bool_t            dbus_message_iter_get_custom      (DBusMessageIter  *iter,
-                                                          char            **name,
-                                                          unsigned char   **value,
-                                                          int              *len);
-
-dbus_bool_t dbus_message_iter_init_array_iterator (DBusMessageIter   *iter,
-						   DBusMessageIter   *array_iter,
-						   int               *array_type);
-dbus_bool_t dbus_message_iter_init_dict_iterator  (DBusMessageIter   *iter,
-						   DBusMessageIter   *dict_iter);
-dbus_bool_t dbus_message_iter_get_byte_array      (DBusMessageIter   *iter,
-						   unsigned char    **value,
-						   int               *len);
-dbus_bool_t dbus_message_iter_get_boolean_array   (DBusMessageIter   *iter,
-						   unsigned char    **value,
-						   int               *len);
-dbus_bool_t dbus_message_iter_get_int32_array     (DBusMessageIter   *iter,
-						   dbus_int32_t     **value,
-						   int               *len);
-dbus_bool_t dbus_message_iter_get_uint32_array    (DBusMessageIter   *iter,
-						   dbus_uint32_t    **value,
-						   int               *len);
-#ifdef DBUS_HAVE_INT64
-dbus_bool_t dbus_message_iter_get_int64_array     (DBusMessageIter   *iter,
-						   dbus_int64_t     **value,
-						   int               *len);
-dbus_bool_t dbus_message_iter_get_uint64_array    (DBusMessageIter   *iter,
-						   dbus_uint64_t    **value,
-						   int               *len);
-#endif /* DBUS_HAVE_INT64 */
-dbus_bool_t dbus_message_iter_get_double_array    (DBusMessageIter   *iter,
-						   double           **value,
-						   int               *len);
-dbus_bool_t dbus_message_iter_get_string_array    (DBusMessageIter   *iter,
-						   char            ***value,
-						   int               *len);
-dbus_bool_t dbus_message_iter_get_object_path_array (DBusMessageIter   *iter,
-                                                     char            ***value,
-                                                     int               *len);
+dbus_bool_t dbus_message_iter_init             (DBusMessage     *message,
+                                                DBusMessageIter *iter);
+dbus_bool_t dbus_message_iter_has_next         (DBusMessageIter *iter);
+dbus_bool_t dbus_message_iter_next             (DBusMessageIter *iter);
+char*       dbus_message_iter_get_signature    (DBusMessageIter *iter);
+int         dbus_message_iter_get_arg_type     (DBusMessageIter *iter);
+int         dbus_message_iter_get_element_type (DBusMessageIter *iter);
+void        dbus_message_iter_recurse          (DBusMessageIter *iter,
+                                                DBusMessageIter *sub);
+void        dbus_message_iter_get_basic        (DBusMessageIter *iter,
+                                                void            *value);
+int         dbus_message_iter_get_array_len    (DBusMessageIter *iter);
+void        dbus_message_iter_get_fixed_array  (DBusMessageIter *iter,
+                                                void            *value,
+                                                int             *n_elements);
 
 
-void        dbus_message_append_iter_init          (DBusMessage          *message,
-						    DBusMessageIter      *iter);
-dbus_bool_t dbus_message_iter_append_nil           (DBusMessageIter      *iter);
-dbus_bool_t dbus_message_iter_append_boolean       (DBusMessageIter      *iter,
-						    dbus_bool_t           value);
-dbus_bool_t dbus_message_iter_append_byte          (DBusMessageIter      *iter,
-						    unsigned char         value);
-dbus_bool_t dbus_message_iter_append_int32         (DBusMessageIter      *iter,
-						    dbus_int32_t          value);
-dbus_bool_t dbus_message_iter_append_uint32        (DBusMessageIter      *iter,
-						    dbus_uint32_t         value);
-#ifdef DBUS_HAVE_INT64
-dbus_bool_t dbus_message_iter_append_int64         (DBusMessageIter      *iter,
-						    dbus_int64_t          value);
-dbus_bool_t dbus_message_iter_append_uint64        (DBusMessageIter      *iter,
-						    dbus_uint64_t         value);
-#endif /* DBUS_HAVE_INT64 */
-dbus_bool_t dbus_message_iter_append_double        (DBusMessageIter      *iter,
-						    double                value);
-dbus_bool_t dbus_message_iter_append_string        (DBusMessageIter      *iter,
-						    const char           *value);
-dbus_bool_t dbus_message_iter_append_object_path   (DBusMessageIter      *iter,
-						    const char           *value);
-dbus_bool_t dbus_message_iter_append_custom        (DBusMessageIter      *iter,
-						    const char           *name,
-						    const unsigned char  *data,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_dict_key      (DBusMessageIter      *iter,
-						    const char           *value);
-dbus_bool_t dbus_message_iter_append_array         (DBusMessageIter      *iter,
-						    DBusMessageIter      *array_iter,
-						    int                   element_type);
-dbus_bool_t dbus_message_iter_append_dict          (DBusMessageIter      *iter,
-						    DBusMessageIter      *dict_iter);
-
-/* Helpers for normal types: */
-dbus_bool_t dbus_message_iter_append_boolean_array (DBusMessageIter      *iter,
-						    unsigned const char  *value,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_int32_array   (DBusMessageIter      *iter,
-						    const dbus_int32_t   *value,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_uint32_array  (DBusMessageIter      *iter,
-						    const dbus_uint32_t  *value,
-						    int                   len);
-#ifdef DBUS_HAVE_INT64
-dbus_bool_t dbus_message_iter_append_int64_array   (DBusMessageIter      *iter,
-						    const dbus_int64_t   *value,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_uint64_array  (DBusMessageIter      *iter,
-						    const dbus_uint64_t  *value,
-						    int                   len);
-#endif /* DBUS_HAVE_INT64 */
-dbus_bool_t dbus_message_iter_append_double_array  (DBusMessageIter      *iter,
-						    const double         *value,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_byte_array    (DBusMessageIter      *iter,
-						    unsigned const char  *value,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_string_array  (DBusMessageIter      *iter,
-						    const char          **value,
-						    int                   len);
-dbus_bool_t dbus_message_iter_append_object_path_array (DBusMessageIter      *iter,
-							const char          **value,
-							int                   len);
-
+void        dbus_message_iter_init_append        (DBusMessage     *message,
+                                                  DBusMessageIter *iter);
+dbus_bool_t dbus_message_iter_append_basic       (DBusMessageIter *iter,
+                                                  int              type,
+                                                  const void      *value);
+dbus_bool_t dbus_message_iter_append_fixed_array (DBusMessageIter *iter,
+                                                  int              element_type,
+                                                  const void      *value,
+                                                  int              n_elements);
+dbus_bool_t dbus_message_iter_open_container     (DBusMessageIter *iter,
+                                                  int              type,
+                                                  const char      *contained_signature,
+                                                  DBusMessageIter *sub);
+dbus_bool_t dbus_message_iter_close_container    (DBusMessageIter *iter,
+                                                  DBusMessageIter *sub);
 
 
 dbus_bool_t  dbus_set_error_from_message  (DBusError    *error,
