@@ -1,5 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
-/* dbus-transport.c DBusTransport object (internal to D-BUS implementation)
+/* dbus-transport.c DBusTransport object (internal to D-Bus implementation)
  *
  * Copyright (C) 2002, 2003  Red Hat Inc.
  *
@@ -68,7 +68,7 @@ live_messages_size_notify (DBusCounter *counter,
   /* disable or re-enable the read watch for the transport if
    * required.
    */
-  if (* transport->vtable->live_messages_changed)
+  if (transport->vtable->live_messages_changed)
     (* transport->vtable->live_messages_changed) (transport);
 
   _dbus_transport_unref (transport);
